[PATCH v3] drm/i915: Explicitly cast divisor and use div_u64()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



As the comment explains, the if check ensures that the divisor oa_period
is a u32. Explicitly cast oa_period to u32 to remove the following
Coccinelle/coccicheck warning reported by do_div.cocci:

  WARNING: do_div() does a 64-by-32 division, please consider using div64_u64 instead

Use the preferred div_u64() function instead of the do_div() macro and
remove the now unnecessary local variable tmp.

Inline the if/else and invert the conditional expression.

Reviewed-by: Jonathan Cavitt <jonathan.cavitt@xxxxxxxxx>
Signed-off-by: Thorsten Blum <thorsten.blum@xxxxxxxxxx>
---
Changes in v2:
- Use div_u64() instead of do_div() after feedback from Ville Syrjälä
- Link to v1: https://lore.kernel.org/linux-kernel/20240710074650.419902-2-thorsten.blum@xxxxxxxxxx/

Changes in v3:
- Inline if/else as suggested by Jonathan Cavitt and Andi Shyti
- Link to v2: https://lore.kernel.org/linux-kernel/20240802160323.46518-2-thorsten.blum@xxxxxxxxxx/
---
 drivers/gpu/drm/i915/i915_perf.c | 10 +++-------
 1 file changed, 3 insertions(+), 7 deletions(-)

diff --git a/drivers/gpu/drm/i915/i915_perf.c b/drivers/gpu/drm/i915/i915_perf.c
index 025a79fe5920..6ff905d2b78f 100644
--- a/drivers/gpu/drm/i915/i915_perf.c
+++ b/drivers/gpu/drm/i915/i915_perf.c
@@ -4063,17 +4063,13 @@ static int read_properties_unlocked(struct i915_perf *perf,
 			oa_period = oa_exponent_to_ns(perf, value);
 
 			/* This check is primarily to ensure that oa_period <=
 			 * UINT32_MAX (before passing to do_div which only
 			 * accepts a u32 denominator), but we can also skip
 			 * checking anything < 1Hz which implicitly can't be
 			 * limited via an integer oa_max_sample_rate.
 			 */
-			if (oa_period <= NSEC_PER_SEC) {
-				u64 tmp = NSEC_PER_SEC;
-				do_div(tmp, oa_period);
-				oa_freq_hz = tmp;
-			} else
-				oa_freq_hz = 0;
+			oa_freq_hz = oa_period > NSEC_PER_SEC ? 0 :
+				div_u64(NSEC_PER_SEC, (u32)oa_period);
 
 			if (oa_freq_hz > i915_oa_max_sample_rate && !perfmon_capable()) {
 				drm_dbg(&perf->i915->drm,
@@ -4063,17 +4063,13 @@ static int read_properties_unlocked(struct i915_perf *perf,
 
 			/* This check is primarily to ensure that oa_period <=
-			 * UINT32_MAX (before passing to do_div which only
+			 * UINT32_MAX (before passing it to div_u64 which only
 			 * accepts a u32 denominator), but we can also skip
 			 * checking anything < 1Hz which implicitly can't be
-- 
2.45.2




[Index of Archives]     [AMD Graphics]     [Linux USB Devel]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]

  Powered by Linux